aboutsummaryrefslogtreecommitdiff
path: root/engines/saga/saga.cpp
diff options
context:
space:
mode:
authorFilippos Karapetis2007-06-15 03:58:21 +0000
committerFilippos Karapetis2007-06-15 03:58:21 +0000
commit4f8f854ee6bd1e681af589a3565ac11ef8bcbc55 (patch)
treed091e443f0f2be7b769353b2afd65e7565667c04 /engines/saga/saga.cpp
parent3b78d79ec0a6051afc99a72340613be370f91654 (diff)
downloadscummvm-rg350-4f8f854ee6bd1e681af589a3565ac11ef8bcbc55.tar.gz
scummvm-rg350-4f8f854ee6bd1e681af589a3565ac11ef8bcbc55.tar.bz2
scummvm-rg350-4f8f854ee6bd1e681af589a3565ac11ef8bcbc55.zip
Forced text is now handled correctly. It's now possible to interact with the video screen in the elder's cave
svn-id: r27410
Diffstat (limited to 'engines/saga/saga.cpp')
-rw-r--r--engines/saga/saga.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/engines/saga/saga.cpp b/engines/saga/saga.cpp
index ea42eac0d7..5aa6c40572 100644
--- a/engines/saga/saga.cpp
+++ b/engines/saga/saga.cpp
@@ -289,8 +289,8 @@ int SagaEngine::go() {
msec = MAX_TIME_DELTA;
}
- // Since Puzzle is actorless, we do it here
- if (_puzzle->isActive()) {
+ // Since Puzzle and forced text are actorless, we do them here
+ if (_puzzle->isActive() || _actor->isForcedTextShown()) {
_actor->handleSpeech(msec);
} else if (!_scene->isInIntro()) {
if (_interface->getMode() == kPanelMain ||